Can i cut and drag a selected object with Pro Dc (Edit PDF)
Description: I have set of blue prints and need to change the order of some electrical devices as shown on the drawing. How do I select and re-position those objec
Keywords: Edit PDF

These forums are now Read Only. If you have an Acrobat question, ask questions and get help from the community.

# Can i cut and drag a selected object with Pro Dc

I have set of blue prints and need to change the order of some electrical devices as shown on the drawing. How do I select and re-position those objects?

Scott Doria

## 1 Answer

Edit Answer (for another 10 minutes)

It won't be easy... Acrobat is not a vector drawing editor, so you will have to work on the elements that make up the objects you want to re-arrange.

With Adobe Acrobat DC Pro, you can find the the content edit tools under Tools>Edit PDF>Edit

Once the tool is selected, you will have to select the individual elements and then move them as one group.

You can also select a larger group, then right-click and e.g. select to edit in Adobe Illustrator (that is, if you have this application installed).

If you can go back to the CAD application that created these blue-prints, that would be the best option.

Karl Heinz Kremer

Please specify a reason:
Spam
Duplicate
Moderate Content
Other
Within this topic

## Browse more answers

- Installation & updates
- Acrobat Reader
- Create PDF
- Edit PDF
- Export PDF
- Review and Comment
- Scan and Optimize
- Mobile PDF
- Protect PDF
- PDF Forms
- Sign and Send PDFs
- Combine Files
- Print Production
- PDF Standards
- Accessibility
- JavaScript